aboutsummaryrefslogtreecommitdiff
path: root/src/test
diff options
context:
space:
mode:
authorbarrystyle <[email protected]>2021-02-20 20:13:43 +0800
committerGitHub <[email protected]>2021-02-20 12:13:43 +0000
commit8f77f8870dcff8d22c4339cd72269cf71a8b1265 (patch)
tree418715cc6d3f5f019f8e596b6b784d5247b67eec /src/test
parentMerge #20933: [0.21] doc: Archive release notes, Add template for minor release (diff)
downloaddiscoin-8f77f8870dcff8d22c4339cd72269cf71a8b1265.tar.xz
discoin-8f77f8870dcff8d22c4339cd72269cf71a8b1265.zip
1.21 codebase rebrand (#1711)
* build: Brand codebase as Dogecoin via automake/autoconf files. * build: Update internal resource files for windows builds. * build: Update internal application names and data directories. * build: Update immediately visible remaining bitcoin name references from cli binaries and qt. * build: Update immediately visible bitcoin references in the main gui itself. * Update functional tests to match Dogecoin * wallet: Add missing check for -descriptors wallet tool option * correct output for functional tests (errorlevels?) Co-authored-by: Ross Nicoll <[email protected]> Co-authored-by: MarcoFalke <[email protected]>
Diffstat (limited to 'src/test')
-rw-r--r--src/test/amount_tests.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/test/amount_tests.cpp b/src/test/amount_tests.cpp
index c16519a6b..92f43eb76 100644
--- a/src/test/amount_tests.cpp
+++ b/src/test/amount_tests.cpp
@@ -98,7 +98,7 @@ BOOST_AUTO_TEST_CASE(BinaryOperatorTest)
BOOST_CHECK(a <= a);
BOOST_CHECK(b >= a);
BOOST_CHECK(b >= b);
// a should be 0.00000002 BTC/kvB now
a += a;
BOOST_CHECK(a == b);
}
@@ -107,9 +107,9 @@ BOOST_AUTO_TEST_CASE(ToStringTest)
{
CFeeRate feeRate;
feeRate = CFeeRate(1);
- BOOST_CHECK_EQUAL(feeRate.ToString(), "0.00000001 BTC/kvB");
- BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::BTC_KVB), "0.00000001 BTC/kvB");
- BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::SAT_VB), "0.001 sat/vB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(), "0.00000001 DOGE/kvB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::BTC_KVB), "0.00000001 DOGE/kvB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::SAT_VB), "0.001 koinu/vB");
}
BOOST_AUTO_TEST_SUITE_END()
@@ -98,7 +98,7 @@ BOOST_AUTO_TEST_CASE(BinaryOperatorTest)
BOOST_CHECK(b >= a);
BOOST_CHECK(b >= b);
- // a should be 0.00000002 BTC/kvB now
+ // a should be 0.00000002 DOGE/kvB now
a += a;
BOOST_CHECK(a == b);